<?php
session_start();
include '../includes/config.php';
include '../includes/functions.php';

if (!isAdminLoggedIn()) {
    header('Location: login.php');
    exit();
}

$appConfig = getAppConfig();
$errors = [];
$success = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    ini_set('memory_limit', '256M');
    
    $data = [
        'app_name' => $_POST['app_name'] ?? '',
        'app_logo' => $appConfig['app_logo'] ?? '',
        'app_logo_url' => $_POST['app_logo_url'] ?? '',
        'app_description' => $_POST['app_description'] ?? '',
        'app_description_image1' => $appConfig['app_description_image1'] ?? '',
        'app_description_image2' => $appConfig['app_description_image2'] ?? '',
        'app_description_image3' => $appConfig['app_description_image3'] ?? '',
        'app_version' => $_POST['app_version'] ?? '',
        'app_download_url' => $_POST['app_download_url'] ?? '',
        'site_title' => $_POST['site_title'] ?? ''
    ];
    
    function handleFileUpload($file, $fieldName, &$data, $maxSize, $appConfig, $isImage = true) {
        global $errors;
        
        if (!empty($file['tmp_name'])) {
            if ($file['size'] > $maxSize * 1024 * 1024) {
                $errors[] = $fieldName . "上传的文件大小不能超过" . $maxSize . "MB。";
                return;
            }
            
            $allowedExtensions = $isImage ? ['jpg', 'jpeg', 'png', 'gif'] : ['apk'];
            $fileExtension = pathinfo($file['name'], PATHINFO_EXTENSION);
            if (!in_array(strtolower($fileExtension), $allowedExtensions)) {
                $errors[] = $fieldName . "文件类型不合法。";
                return;
            }
            
            $uploadDir = $_SERVER['DOCUMENT_ROOT'] . '/xingyun/assets/uploads/';
            if (!file_exists($uploadDir)) {
                mkdir($uploadDir, 0777, true);
            }
            
            $fileName = uniqid() . '.' . $fileExtension;
            $uploadFile = $uploadDir . $fileName;
            
            if (move_uploaded_file($file['tmp_name'], $uploadFile)) {
                $data[$fieldName] = '/xingyun/assets/uploads/' . $fileName;
            } else {
                $errors[] = $fieldName . "文件上传失败。";
            }
        }
    }
    
    if (!empty($_FILES['app_logo']['tmp_name'])) {
        handleFileUpload($_FILES['app_logo'], 'app_logo', $data, 5, $appConfig);
    }
    
    if (!empty($_FILES['app_description_image1']['tmp_name'])) {
        handleFileUpload($_FILES['app_description_image1'], 'app_description_image1', $data, 5, $appConfig);
    }
    
    if (!empty($_FILES['app_description_image2']['tmp_name'])) {
        handleFileUpload($_FILES['app_description_image2'], 'app_description_image2', $data, 5, $appConfig);
    }
    
    if (!empty($_FILES['app_description_image3']['tmp_name'])) {
        handleFileUpload($_FILES['app_description_image3'], 'app_description_image3', $data, 5, $appConfig);
    }
    
    if (!empty($_FILES['app_download_file']['tmp_name'])) {
        handleFileUpload($_FILES['app_download_file'], 'app_download_file', $data, 50, $appConfig, false);
    }
    
    if (empty($errors) && updateAppConfig($data)) {
        $success = '应用配置更新成功！';
        $appConfig = getAppConfig();
    } else {
        $errors[] = '应用配置更新失败，请重试。';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>星云-APP下载页管理系统</title>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
    <style>
        :root {
            --primary-color: #3498db;
            --primary-dark: #2980b9;
            --secondary-color: #2c3e50;
            --light-color: #f5f7fa;
            --text-color: #333;
            --border-color: #ecf0f1;
            --success-color: #2ecc71;
            --danger-color: #e74c3c;
        }

        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
            font-family: 'Segoe UI', 'Microsoft YaHei', sans-serif;
        }
        
        body {
            background-color: var(--light-color);
            color: var(--text-color);
            line-height: 1.6;
        }
        
        .container {
            width: 100%;
            max-width: 1200px;
            margin: 0 auto;
            padding: 0 15px;
        }
        
        header {
            background-color: white;
            box-shadow: 0 2px 10px rgba(0,0,0,0.1);
            padding: 15px 20px;
            position: sticky;
            top: 0;
            z-index: 100;
        }
        
        .header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            flex-wrap: wrap;
        }
        
        .logo {
            display: flex;
            align-items: center;
            gap: 10px;
            margin-bottom: 10px;
        }
        
        .logo h1 {
            font-size: 22px;
            font-weight: 600;
            color: var(--secondary-color);
        }
        
        .logo i {
            font-size: 24px;
            color: var(--primary-color);
        }
        
        .nav {
            display: flex;
            gap: 15px;
            flex-wrap: wrap;
        }
        
        .nav a {
            text-decoration: none;
            color: var(--secondary-color);
            font-weight: 500;
            padding: 8px 12px;
            border-radius: 6px;
            transition: all 0.3s ease;
            display: flex;
            align-items: center;
            gap: 5px;
        }
        
        .nav a i {
            font-size: 16px;
        }
        
        .nav a:hover, .nav a.active {
            background-color: var(--primary-color);
            color: white;
        }
        
        .main-content {
            display: grid;
            grid-template-columns: 1fr;
            gap: 25px;
            margin-top: 20px;
        }
        
        .card {
            background: white;
            border-radius: 12px;
            box-shadow: 0 4px 15px rgba(0, 0, 0, 0.08);
            padding: 25px;
            transition: transform 0.3s, box-shadow 0.3s;
        }
        
        .card:hover {
            transform: translateY(-5px);
            box-shadow: 0 8px 20px rgba(0, 0, 0, 0.12);
        }
        
        .card-title {
            font-size: 18px;
            font-weight: 600;
            color: var(--secondary-color);
            margin-bottom: 20px;
            padding-bottom: 10px;
            border-bottom: 2px solid var(--border-color);
            display: flex;
            align-items: center;
            gap: 10px;
        }
        
        .card-title i {
            color: var(--primary-color);
        }
        
        .form-group {
            margin-bottom: 20px;
        }
        
        .form-group label {
            display: block;
            margin-bottom: 8px;
            font-weight: 500;
            color: var(--secondary-color);
        }
        
        .form-control {
            width: 100%;
            padding: 12px 15px;
            border: 1px solid #ddd;
            border-radius: 5px;
            font-size: 14px;
            transition: border-color 0.3s;
        }
        
        .form-control:focus {
            border-color: var(--primary-color);
            outline: none;
        }
        
        .form-row {
            display: flex;
            gap: 20px;
            margin-bottom: 20px;
        }
        
        .form-row > div {
            flex: 1;
        }
        
        .image-preview {
            margin-top: 10px;
            text-align: center;
        }
        
        .image-preview img {
            max-width: 100%;
            max-height: 150px;
            border-radius: 5px;
        }
        
        .btn {
            background: var(--primary-color);
            color: white;
            border: none;
            padding: 12px 25px;
            border-radius: 5px;
            font-size: 16px;
            font-weight: 500;
            cursor: pointer;
            transition: background 0.3s;
        }
        
        .btn:hover {
            background: var(--primary-dark);
        }
        
        .alert {
            padding: 15px;
            border-radius: 5px;
            margin-bottom: 20px;
        }
        
        .alert-success {
            background-color: #d4edda;
            color: #155724;
        }
        
        .alert-danger {
            background-color: #f8d7da;
            color: #721c24;
        }
        
        .section-title {
            font-size: 16px;
            font-weight: 600;
            color: var(--secondary-color);
            margin-bottom: 15px;
            padding-bottom: 8px;
            border-bottom: 1px solid var(--border-color);
        }
        
        .file-upload-group {
            display: flex;
            flex-direction: column;
            gap: 10px;
            margin-bottom: 10px;
        }
        
        .loading {
            display: none;
            text-align: center;
            padding: 20px;
        }
        
        .loading.active {
            display: block;
        }

        @media (max-width: 768px) {
            .form-row {
                flex-direction: column;
                gap: 15px;
            }
        }
    </style>
</head>
<body>
    <header>
        <div class="container">
            <div class="header">
                <div class="logo">
                    <i class="fas fa-chart-line"></i>
                    <h1>星云-APP下载页管理系统</h1>
                </div>
                <div class="nav">
                    <a href="index.php"><i class="fas fa-tachometer-alt"></i><span>仪表盘</span></a>
                    <a href="config.php" class="active"><i class="fas fa-cogs"></i><span>应用配置</span></a>
                    <a href="change_password.php"><i class="fas fa-lock"></i><span>修改密码</span></a>
                    <a href="logout.php"><i class="fas fa-sign-out-alt"></i><span>退出登录</span></a>
                </div>
            </div>
        </div>
    </header>
    
    <div class="container">
        <div class="main-content">
            <div class="card">
                <h2 class="card-title"><i class="fas fa-cogs"></i> 应用配置</h2>
                
                <?php if (!empty($errors)): ?>
                    <div class="alert alert-danger">
                        <ul>
                            <?php foreach ($errors as $error): ?>
                                <li><?php echo $error; ?></li>
                            <?php endforeach; ?>
                        </ul>
                    </div>
                <?php endif; ?>
                
                <?php if ($success): ?>
                    <div class="alert alert-success">
                        <?php echo $success; ?>
                    </div>
                <?php endif; ?>
                
                <form method="POST" enctype="multipart/form-data" id="appConfigForm">
                    <div class="form-row">
                        <div>
                            <div class="form-group">
                                <label for="app_name">名称</label>
                                <input type="text" id="app_name" name="app_name" class="form-control" value="<?= htmlspecialchars($appConfig['app_name'] ?? '') ?>" required>
                            </div>
                            
                         <div class="form-group">
                                <label>LOGO</label>
                                <div class="file-upload-group">
                                    <input type="file" name="app_logo" accept="image/*" class="form-control">
                                    <input type="text" id="app_logo_url" name="app_logo_url" class="form-control" placeholder="上传或输入LOGO URL" value="<?= htmlspecialchars($appConfig['app_logo_url'] ?? '') ?>">
                                </div>
                                <div class="image-preview">
                                    <img src="<?= htmlspecialchars($appConfig['app_logo'] ?? '') ?>" alt="LOGO" style="max-width: 100px; max-height: 100px;">
                                </div>
                            </div>
                        </div>  
                        
                        <div>
                            <div class="form-group">
                                <label for="app_version">应用版本</label>
                                <input type="text" id="app_version" name="app_version" class="form-control" value="<?= htmlspecialchars($appConfig['app_version'] ?? '') ?>" required>
                            </div>
                            
                            <div class="form-group">
                                <label for="site_title">网站标题</label>
                                <input type="text" id="site_title" name="site_title" class="form-control" value="<?= htmlspecialchars($appConfig['site_title'] ?? '') ?>" required>
                            </div>
                        </div>
                    </div>
                    
                    <div class="form-group">
                        <label for="app_description">简介</label>
                        <textarea id="app_description" name="app_description" class="form-control" rows="4" required><?= htmlspecialchars($appConfig['app_description'] ?? '') ?></textarea>
                    </div>
                    
                    <div class="section-title">简介图</div>
                    <div class="form-row">
                        <div>
                            <label for="app_description_image1">简介图1</label>
                            <div class="file-upload-group">
                                <input type="file" name="app_description_image1" accept="image/*" class="form-control">
                                <input type="text" id="app_description_image1" name="app_description_image1" class="form-control" placeholder="上传或输入简介图URL" value="<?= htmlspecialchars($appConfig['app_description_image1'] ?? '') ?>">
                            </div>
                            <div class="image-preview">
                                <img src="<?= htmlspecialchars($appConfig['app_description_image1'] ?? '') ?>" alt="应用简介图1" style="max-width: 100%; max-height: 100px;">
                            </div>
                        </div>
                        
                        <div>
                            <label for="app_description_image2">简介图2</label>
                            <div class="file-upload-group">
                                <input type="file" name="app_description_image2" accept="image/*" class="form-control">
                                <input type="text" id="app_description_image2" name="app_description_image2" class="form-control" placeholder="上传或输入简介图URL" value="<?= htmlspecialchars($appConfig['app_description_image2'] ?? '') ?>">
                            </div>
                            <div class="image-preview">
                                <img src="<?= htmlspecialchars($appConfig['app_description_image2'] ?? '') ?>" alt="应用简介图2" style="max-width: 100%; max-height: 100px;">
                            </div>
                        </div>
                    </div>
                    
                    <div class="form-row">
                        <div>
                            <label for="app_description_image3">简介图3</label>
                            <div class="file-upload-group">
                                <input type="file" name="app_description_image3" accept="image/*" class="form-control">
                                <input type="text" id="app_description_image3" name="app_description_image3" class="form-control" placeholder="上传或输入简介图URL" value="<?= htmlspecialchars($appConfig['app_description_image3'] ?? '') ?>">
                            </div>
                            <div class="image-preview">
                                <img src="<?= htmlspecialchars($appConfig['app_description_image3'] ?? '') ?>" alt="应用简介图3" style="max-width: 100%; max-height: 100px;">
                            </div>
                        </div>
                    </div>
                    
                    <div class="section-title">下载设置</div>
                    <div class="form-group">
                        <label>应用下载方式</label>
                        <div class="radio-group">
                            <label class="radio-option">
                                <input type="radio" id="download_type_url" name="download_type" value="url" <?= isset($appConfig['app_download_url']) && !empty($appConfig['app_download_url']) ? 'checked' : '' ?>>
                                <span>URL链接</span>
                            </label>
                            <label class="radio-option">
                                <input type="radio" id="download_type_file" name="download_type" value="file" <?= isset($appConfig['app_download_file']) && !empty($appConfig['app_download_file']) ? 'checked' : '' ?>>
                                <span>上传安装包</span>
                            </label>
                        </div>
                    </div>
                    
                    <div class="form-group">
                        <label for="app_download_url">下载链接URL</label>
                        <input type="text" id="app_download_url" name="app_download_url" class="form-control" placeholder="应用下载链接URL" value="<?= htmlspecialchars($appConfig['app_download_url'] ?? '') ?>">
                    </div>
                    
                    <div class="form-group">
                        <label>上传APK文件</label>
                        <div class="file-upload-group">
                            <input type="file" name="app_download_file" accept=".apk" class="form-control">
                        </div>
                    </div>
                    
                    <div class="loading" id="loading">正在保存中，请稍候...</div>
                    <button type="submit" class="btn" id="submitButton">保存配置</button>
                </form>
            </div>
        </div>
    </div>

    <script>
        document.addEventListener('DOMContentLoaded', function() {
            const form = document.getElementById('appConfigForm');
            const submitButton = document.getElementById('submitButton');
            const loading = document.getElementById('loading');
            
            const fileInputs = document.querySelectorAll('input[type="file"]');
            fileInputs.forEach(input => {
                input.addEventListener('change', function() {
                    const file = this.files[0];
                    if (!file) return;
                    
                    if (this.name.includes('image')) {
                        const preview = this.closest('.file-upload-group').nextElementSibling;
                        if (preview && preview.classList.contains('image-preview')) {
                            const img = preview.querySelector('img');
                            const reader = new FileReader();
                            reader.onload = function(e) {
                                img.src = e.target.result;
                            };
                            reader.readAsDataURL(file);
                        }
                    }
                });
            });
            
            form.addEventListener('submit', function(e) {
                e.preventDefault();
                
                submitButton.style.display = 'none';
                loading.classList.add('active');
                
                const requiredInputs = document.querySelectorAll('input[required], textarea[required]');
                let isValid = true;
                
                requiredInputs.forEach(input => {
                    if (!input.value.trim()) {
                        isValid = false;
                        input.style.borderColor = '#e74c3c';
                    } else {
                        input.style.borderColor = '#ddd';
                    }
                });
                
                if (!isValid) {
                    submitButton.style.display = 'block';
                    loading.classList.remove('active');
                    alert('请填写所有必填字段！');
                    return;
                }
                
                form.submit();
            });
        });
    </script>
</body>
</html>
