<?php
session_start();
include '../includes/config.php';
include '../includes/functions.php';

if (!isAdminLoggedIn()) {
    header('Location: login.php');
    exit();
}

$systemInfo = getSystemInfo();
$downloadStats = getDownloadStats();
$appConfig = getAppConfig();
?>

<!DOCTYPE html>
<html lang="zh-CN">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>星云-APP下载页管理系统</title>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
    <style>
        :root {
            --primary-color: #3498db;
            --primary-dark: #2980b9;
            --secondary-color: #2c3e50;
            --light-color: #f5f7fa;
            --text-color: #333;
            --border-color: #ecf0f1;
            --success-color: #2ecc71;
        }

        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
            font-family: 'Segoe UI', 'Microsoft YaHei', sans-serif;
        }
        
        body {
            background-color: var(--light-color);
            color: var(--text-color);
            line-height: 1.6;
        }
        
        .container {
            width: 100%;
            max-width: 1200px;
            margin: 0 auto;
            padding: 0 15px;
        }
        
        header {
            background-color: white;
            box-shadow: 0 2px 10px rgba(0,0,0,0.1);
            padding: 15px 20px;
            position: sticky;
            top: 0;
            z-index: 100;
        }
        
        .header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            flex-wrap: wrap;
        }
        
        .logo {
            display: flex;
            align-items: center;
            gap: 10px;
            margin-bottom: 10px;
        }
        
        .logo h1 {
            font-size: 22px;
            font-weight: 600;
            color: var(--secondary-color);
        }
        
        .logo i {
            font-size: 24px;
            color: var(--primary-color);
        }
        
        .nav {
            display: flex;
            gap: 15px;
            flex-wrap: wrap;
        }
        
        .nav a {
            text-decoration: none;
            color: var(--secondary-color);
            font-weight: 500;
            padding: 8px 12px;
            border-radius: 6px;
            transition: all 0.3s ease;
            display: flex;
            align-items: center;
            gap: 5px;
        }
        
        .nav a i {
            font-size: 16px;
        }
        
        .nav a:hover, .nav a.active {
            background-color: var(--primary-color);
            color: white;
        }
        
        .main-content {
            display: grid;
            grid-template-columns: 1fr;
            gap: 25px;
            margin-top: 20px;
        }
        
        .card {
            background: white;
            border-radius: 12px;
            box-shadow: 0 4px 15px rgba(0, 0, 0, 0.08);
            padding: 25px;
            transition: transform 0.3s, box-shadow 0.3s;
        }
        
        .card:hover {
            transform: translateY(-5px);
            box-shadow: 0 8px 20px rgba(0, 0, 0, 0.12);
        }
        
        .card-title {
            font-size: 18px;
            font-weight: 600;
            color: var(--secondary-color);
            margin-bottom: 20px;
            padding-bottom: 10px;
            border-bottom: 2px solid var(--border-color);
            display: flex;
            align-items: center;
            gap: 10px;
        }
        
        .card-title i {
            color: var(--primary-color);
        }
        
        .dashboard-stats {
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(250px, 1fr));
            gap: 20px;
        }
        
        .stat-card {
            background: linear-gradient(135deg, var(--primary-color), var(--primary-dark));
            color: white;
            border-radius: 10px;
            padding: 25px;
            display: flex;
            flex-direction: column;
            justify-content: space-between;
            transition: transform 0.3s;
        }
        
        .stat-card:hover {
            transform: scale(1.03);
        }
        
        .stat-header {
            font-size: 14px;
            opacity: 0.9;
        }
        
        .stat-value {
            font-size: 28px;
            font-weight: 700;
            margin: 10px 0;
            display: flex;
            align-items: center;
            gap: 10px;
        }
        
        .stat-value i {
            font-size: 24px;
        }
        
        .stat-footer {
            font-size: 14px;
            opacity: 0.8;
            display: flex;
            align-items: center;
            gap: 5px;
        }
        
        .time-value {
            font-size: 24px;
            font-weight: 600;
            color: var(--secondary-color);
            margin-bottom: 5px;
        }
        
        .time-label {
            font-size: 14px;
            color: #7f8c8d;
        }
        
        .status-indicator {
            display: inline-block;
            width: 10px;
            height: 10px;
            border-radius: 50%;
            margin-right: 8px;
        }
        
        .status-active {
            background-color: var(--success-color);
        }
        
        .server-info {
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(250px, 1fr));
            gap: 20px;
            margin-top: 20px;
        }
        
        .server-info-item {
            background: white;
            border-radius: 10px;
            padding: 20px;
            box-shadow: 0 2px 8px rgba(0, 0, 0, 0.05);
            display: flex;
            align-items: center;
            gap: 15px;
        }
        
        .server-info-icon {
            width: 50px;
            height: 50px;
            background-color: rgba(52, 152, 219, 0.1);
            border-radius: 12px;
            display: flex;
            align-items: center;
            justify-content: center;
            color: var(--primary-color);
            font-size: 20px;
        }
        
        .server-info-content h4 {
            font-size: 16px;
            margin-bottom: 5px;
            color: var(--secondary-color);
        }
        
        .server-info-content p {
            font-size: 14px;
            color: #7f8c8d;
        }
        
        @media (max-width: 768px) {
            .dashboard-stats,
            .server-info {
                grid-template-columns: 1fr;
            }
            
            .stat-card,
            .server-info-item {
                padding: 15px;
            }
            
            .stat-header {
                font-size: 12px;
            }
            
            .stat-value {
                font-size: 22px;
            }
        }
        
        @media (max-width: 480px) {
            .header {
                flex-direction: column;
                align-items: flex-start;
            }
            
            .nav {
                width: 100%;
                justify-content: space-between;
                margin-top: 15px;
            }
            
            .nav a {
                padding: 6px;
            }
            
            .nav a span {
                font-size: 12px;
            }
            
            .card {
                padding: 15px;
            }
            
            .card-title {
                font-size: 16px;
            }
            
            .stat-card {
                padding: 15px;
            }
            
            .stat-value {
                font-size: 20px;
            }
        }
    </style>
</head>
<body>
    <header>
        <div class="container">
            <div class="header">
                <div class="logo">
                    <i class="fas fa-chart-line"></i>
                    <h1>星云-APP下载页管理系统</h1>
                </div>
                <div class="nav">
                    <a href="index.php" class="active"><i class="fas fa-tachometer-alt"></i><span>仪表盘</span></a>
                    <a href="config.php"><i class="fas fa-cogs"></i><span>应用配置</span></a>
                    <a href="change_password.php"><i class="fas fa-lock"></i><span>修改密码</span></a>
                    <a href="logout.php"><i class="fas fa-sign-out-alt"></i><span>退出登录</span></a>
                </div>
            </div>
        </div>
    </header>
    
    <div class="container">
        <div class="main-content">
            <div class="card">
                <h2 class="card-title"><i class="fas fa-server"></i> 系统信息</h2>
                <div class="dashboard-stats">
                    <div class="stat-card">
                        <div>
                            <div class="stat-header">当前时间</div>
                            <div class="stat-value">
                                <i class="fas fa-clock"></i>
                                <span id="current-time">加载中...</span>
                            </div>
                            <div class="stat-footer">
                                <i class="fas fa-calendar"></i>
                                <span id="current-date"></span>
                            </div>
                        </div>
                    </div>
                    <div class="stat-card">
                        <div>
                            <div class="stat-header">服务器状态</div>
                            <div class="stat-value">
                                <i class="fas fa-server"></i>
                                <span>运行中</span>
                            </div>
                            <div class="stat-footer">
                                <span class="status-indicator status-active"></span>
                                正常
                            </div>
                        </div>
                    </div>
                    <div class="stat-card">
                        <div>
                            <div class="stat-header">PHP版本</div>
                            <div class="stat-value">
                                <i class="fab fa-php"></i>
                                <span><?= $systemInfo['php_version'] ?></span>
                            </div>
                            <div class="stat-footer">
                                <span class="status-indicator status-active"></span>
                                最新
                            </div>
                        </div>
                    </div>
                    <div class="stat-card">
                        <div>
                            <div class="stat-header">MySQL版本</div>
                            <div class="stat-value">
                                <i class="fas fa-database"></i>
                                <span><?= $systemInfo['mysql_version'] ?></span>
                            </div>
                            <div class="stat-footer">
                                <span class="status-indicator status-active"></span>
                                正常
                            </div>
                        </div>
                    </div>
                    <div class="stat-card">
                        <div>
                            <div class="stat-header">站点版本</div>
                            <div class="stat-value">
                                <i class="fas fa-code"></i>
                                <span>v1.2</span>
                            </div>
                            
                                
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            
            <div class="card">
                <h2 class="card-title"><i class="fas fa-chart-bar"></i> 统计信息</h2>
                <div class="dashboard-stats">
                    <div class="stat-card" style="grid-column: 1 / -1;">
                        <div>
                            <div class="stat-header">总下载量</div>
                            <div class="stat-value">
                                <i class="fas fa-download"></i>
                                <span><?= $downloadStats ?></span>
                            </div>
                            <div class="stat-footer">
                                <i class="fas fa-history"></i>
                                最近更新: <span id="last-update">实时</span>
                            </div>
                        </div>
                    </div>
                </div>
                
                <div class="server-info">
                    <div class="server-info-item">
                        <div class="server-info-icon">
                            <i class="fas fa-server"></i>
                        </div>
                        <div class="server-info-content">
                            <h4>服务器信息</h4>
                            <p><?= $systemInfo['server_software'] ?></p>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    
    <script>
        function updateDateTime() {
            const now = new Date();
            const timeOptions = { hour: '2-digit', minute: '2-digit', second: '2-digit' };
            const dateOptions = { year: 'numeric', month: 'long', day: 'numeric' };
            
            document.getElementById('current-time').textContent = now.toLocaleTimeString('zh-CN', timeOptions);
            document.getElementById('current-date').textContent = now.toLocaleDateString('zh-CN', dateOptions);
        }
        
        updateDateTime();
        setInterval(updateDateTime, 1000);
        
        document.addEventListener('DOMContentLoaded', function() {
            document.getElementById('last-update').textContent = new Date().toLocaleTimeString('zh-CN', { hour: '2-digit', minute: '2-digit' });
        });
    </script>
</body>
</html>
